==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/de-if/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Der Nutzer kann sich einloggen',
    'activated_disabled_help_text' => 'Du kannst den Aktivierungsstatus für deinen eigenen Account nicht bearbeiten.',
    'assets_user'       => 'Assets zugewiesen an :name',
    'bulk_update_warn'	=> 'Du bist dabei, die Eigenschaften von :user_count Benutzern zu bearbeiten. Bitte beachte, dass du deine eigenen Benutzerattribute nicht über dieses Formular ändern kannst und Änderungen an deinem eigenen Benutzer einzeln vornehmen musst.',
    'bulk_update_help'	=> 'Hier können mehrere Benutzer gleichzeitig bearbeitet werden. Nur Felder ausfüllen, welche geändert werden sollen. Leere Felder werden nicht geändert.',
    'current_assets'    => 'Asset wurde an nachfolgenden Benutzer ausgegeben',
    'clone'             => 'Benutzer kopieren',
    'contact_user'      => 'Kontakt :name',
    'edit'              => 'Benutzer bearbeiten',
    'filetype_info'     => 'Erlaubte Dateitypen sind png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, und rar.',
    'history_user'      => 'Historie von :name',
    'info'				=> 'Info',
    'restore_user'		=> 'Klicke hier, um sie wiederherzustellen.',
    'last_login'        => 'Letzte Anmeldung',
    'ldap_config_text'  => 'Die LDAP Konfigurations Einstellungen findest Du hier Admin -> Einstellungen. Der (optional) wählbare Standort wird für alle importierten Benutzer gesetzt.',
    'print_assigned'    => 'Alles Zugewiesene drucken',
    'email_assigned'    => 'E-Mail-Liste aller Zugewiesenen',
    'user_notified'     => 'Der Benutzer hat eine Liste seiner aktuell zugewiesenen Artikel per E-Mail erhalten.',
    'auto_assign_label' => 'Diesen Benutzer bei der automatischen Zuweisung berechtigter Lizenzen einbeziehen',
    'auto_assign_help'  => 'Diesen Benutzer bei der automatischen Zuweisung von Lizenzen überspringen',
    'software_user'     => 'Software herausgegeben an :name',
    'send_email_help'   => 'Du musst eine E-Mail-Adresse angeben, um dem Benutzer Zugangsdaten zu zusenden. Das Versenden von Zugangsdaten ist nur bei der Erstellung eines Benutzers möglich. Passwörter werden in einem Einweg-Hash gespeichert und können danach nicht mehr ausgelesen werden.',
    'view_user'         => 'Benutzer :name ansehen',
    'usercsv'           => 'CSV Datei',
    'two_factor_admin_optin_help' => 'Ihre aktuellen Administrator-Einstellungen erlauben die selektive Durchführung der Zwei-Faktor-Authentifizierung.  ',
    'two_factor_enrolled' => '2FA-Gerät registriert ',
    'two_factor_active'   => '2FA aktiv ',
    'user_deactivated'  => 'Benutzer kann sich nicht anmelden',
    'user_activated'  => 'Benutzer kann sich anmelden',
    'activation_status_warning' => 'Aktivierungsstatus nicht ändern',
    'group_memberships_helpblock' => 'Nur Superadministratoren können Gruppenmitgliedschaften bearbeiten.',
    'superadmin_permission_warning' => 'Nur Superadmins dürfen einem Benutzer Superadmin Zugriff gewähren.',
    'admin_permission_warning' => 'Nur Benutzer mit Administratorrechten oder höher dürfen einem Benutzer Administratorzugriff gewähren.',
    'remove_group_memberships' => 'Gruppenmitgliedschaften entfernen',
    'warning_deletion_information' => 'Du bist dabei, ALLE Assets von :count Benutzer(s) einzuchecken. Super-Admins werden rot hervorgehoben.',
    'update_user_assets_status' => 'Alle Assets für diese Benutzer auf diesen Status aktualisieren',
    'checkin_user_properties' => 'Alle diesen Benutzern zugeordneten Objekte zurücknehmen',
    'remote_label'   => 'Dies ist ein externer Benutzer',
    'remote'   => 'Extern',
    'remote_help' => 'Dies kann nützlich sein, wenn du nach externen Benutzern filtern musst, die niemals oder nur selten an Ihre physischen Standorte kommen.',
    'not_remote_label' => 'Dies ist kein externer Benutzer',
    'vip_label' => 'VIP Benutzer',
    'vip_help' => 'Dies kann hilfreich sein, um wichtige Personen zu markieren, wenn du möchtest.',
    'create_user' => 'Benutzer erstellen',
    'create_user_page_explanation' => 'Dies sind die Anmeldeinformationen, die du verwendest, um zum ersten Mal auf die Webseite zuzugreifen.',
    'email_credentials' => 'E-Mail-Anmeldedaten',
    'email_credentials_text' => 'Meine Zugangsdaten an die oben genannte E-Mail-Adresse senden',
    'next_save_user' => 'Weiter: Benutzer speichern',
    'all_assigned_list_generation' => 'Generiert am:',
    'email_user_creds_on_create' => 'Diesem Benutzer seine Zugangsdaten per E-Mail senden?',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/de-if/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Der Nutzer kann sich einloggen',
    'activated_disabled_help_text' => 'Du kannst den Aktivierungsstatus für deinen eigenen Account nicht bearbeiten.',
    'assets_user'       => 'Assets zugewiesen an :name',
    'bulk_update_warn'	=> 'Du bist dabei, die Eigenschaften von :user_count Benutzern zu bearbeiten. Bitte beachte, dass du deine eigenen Benutzerattribute nicht über dieses Formular ändern kannst und Änderungen an deinem eigenen Benutzer einzeln vornehmen musst.',
    'bulk_update_help'	=> 'Hier können mehrere Benutzer gleichzeitig bearbeitet werden. Nur Felder ausfüllen, welche geändert werden sollen. Leere Felder werden nicht geändert.',
    'current_assets'    => 'Asset wurde an nachfolgenden Benutzer ausgegeben',
    'clone'             => 'Benutzer kopieren',
    'contact_user'      => 'Kontakt :name',
    'edit'              => 'Benutzer bearbeiten',
    'filetype_info'     => 'Erlaubte Dateitypen sind png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, und rar.',
    'history_user'      => 'Historie von :name',
    'info'				=> 'Info',
    'restore_user'		=> 'Klicke hier, um sie wiederherzustellen.',
    'last_login'        => 'Letzte Anmeldung',
    'ldap_config_text'  => 'Die LDAP Konfigurations Einstellungen findest Du hier Admin -> Einstellungen. Der (optional) wählbare Standort wird für alle importierten Benutzer gesetzt.',
    'print_assigned'    => 'Alles Zugewiesene drucken',
    'email_assigned'    => 'E-Mail-Liste aller Zugewiesenen',
    'user_notified'     => 'Der Benutzer hat eine Liste seiner aktuell zugewiesenen Artikel per E-Mail erhalten.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Diesen Benutzer bei der automatischen Zuweisung berechtigter Lizenzen einbeziehen',
    'auto_assign_help'  => 'Diesen Benutzer bei der automatischen Zuweisung von Lizenzen überspringen',
    'software_user'     => 'Software herausgegeben an :name',
    'send_email_help'   => 'Du musst eine E-Mail-Adresse angeben, um dem Benutzer Zugangsdaten zu zusenden. Das Versenden von Zugangsdaten ist nur bei der Erstellung eines Benutzers möglich. Passwörter werden in einem Einweg-Hash gespeichert und können danach nicht mehr ausgelesen werden.',
    'view_user'         => 'Benutzer :name ansehen',
    'usercsv'           => 'CSV Datei',
    'two_factor_admin_optin_help' => 'Ihre aktuellen Administrator-Einstellungen erlauben die selektive Durchführung der Zwei-Faktor-Authentifizierung.  ',
    'two_factor_enrolled' => '2FA-Gerät registriert ',
    'two_factor_active'   => '2FA aktiv ',
    'user_deactivated'  => 'Benutzer kann sich nicht anmelden',
    'user_activated'  => 'Benutzer kann sich anmelden',
    'activation_status_warning' => 'Aktivierungsstatus nicht ändern',
    'group_memberships_helpblock' => 'Nur Superadministratoren können Gruppenmitgliedschaften bearbeiten.',
    'superadmin_permission_warning' => 'Nur Superadmins dürfen einem Benutzer Superadmin Zugriff gewähren.',
    'admin_permission_warning' => 'Nur Benutzer mit Administratorrechten oder höher dürfen einem Benutzer Administratorzugriff gewähren.',
    'remove_group_memberships' => 'Gruppenmitgliedschaften entfernen',
    'warning_deletion_information' => 'Du bist dabei, ALLE Assets von :count Benutzer(s) einzuchecken. Super-Admins werden rot hervorgehoben.',
    'update_user_assets_status' => 'Alle Assets für diese Benutzer auf diesen Status aktualisieren',
    'checkin_user_properties' => 'Alle diesen Benutzern zugeordneten Objekte zurücknehmen',
    'remote_label'   => 'Dies ist ein externer Benutzer',
    'remote'   => 'Extern',
    'remote_help' => 'Dies kann nützlich sein, wenn du nach externen Benutzern filtern musst, die niemals oder nur selten an Ihre physischen Standorte kommen.',
    'not_remote_label' => 'Dies ist kein externer Benutzer',
    'vip_label' => 'VIP Benutzer',
    'vip_help' => 'Dies kann hilfreich sein, um wichtige Personen zu markieren, wenn du möchtest.',
    'create_user' => 'Benutzer erstellen',
    'create_user_page_explanation' => 'Dies sind die Anmeldeinformationen, die du verwendest, um zum ersten Mal auf die Webseite zuzugreifen.',
    'email_credentials' => 'E-Mail-Anmeldedaten',
    'email_credentials_text' => 'Meine Zugangsdaten an die oben genannte E-Mail-Adresse senden',
    'next_save_user' => 'Weiter: Benutzer speichern',
    'all_assigned_list_generation' => 'Generiert am:',
    'email_user_creds_on_create' => 'Diesem Benutzer seine Zugangsdaten per E-Mail senden?',
];
